# Changelog for `clap`

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog], and this project adheres to
[Semantic Versioning].

[Keep a Changelog]: https://keepachangelog.com/en/1.0.0/
[Semantic Versioning]: https://semver.org/


## [Unreleased](https://github.com/bbugyi200/clap/compare/0.2.1...HEAD)

No notable changes have been made.

## [0.2.1](https://github.com/bbugyi200/clap/compare/0.2.0...0.2.1) - 2021-09-26

### Fixed

* Added `importlib-metadata` package as direct dependency of this package.

## [0.2.0](https://github.com/bbugyi200/clap/compare/0.1.0...0.2.0) - 2021-09-26

### Added

* Copied code from `bugyi.lib.cli` module.

## [0.1.0](https://github.com/bbugyi200/clap/releases/tag/0.1.0) - 2021-09-26

### Miscellaneous

* First release.
